@@ -33,9 +33,10 @@
 #  define KPLOTTING_DEPRECATED_NO_EXPORT KPLOTTING_NO_EXPORT KPLOTTING_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPLOTTING_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPLOTTING_NO_DEPRECATED
+#    define KPLOTTING_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
